/*
 * Convert a DECnet address to an ethernet MAC address
 * (C) 1997 Steven Whitehouse
 */
#include <stdio.h>

void usage(void)
{
  fprintf(stderr, "Usage:\n"
	  "dn2ether-addr <dnaddr>\n\n"
	  "where <dnaddr> is a valid DECnet address of the form\n"
	  "       area.node\n"
	  "          with 0 <= area <= 63\n"
	  "          and  0 <= node <= 1023\n");
}


int main(int argc, char *argv[])
{
  unsigned long area, node;

  if (argc != 2)
    {
      usage();
      exit(-1);
    }

  if (sscanf(argv[1], "%lu.%lu", &area, &node) != 2)
    {
      usage();
      exit(-1);
    }

  if (area > 63)
    {
      fprintf(stderr, "Error: Area must be between 0 and 63\n");
      usage();
      exit(-1);
    }

  if (node > 1023)
    {
      fprintf(stderr, "Error: Node must be between 0 and 1023\n");
      usage();
      exit(-1);
    }

  printf("AA:00:04:00:%02lX:%02lX\n", node & 0xff, (area << 2) | (node >> 8));

  return 0;
}
